#
# spec file for package monitoring-plugins-sar-perf
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           monitoring-plugins-sar-perf
Summary:        Get performance data from sar 
License:        BSD-2-Clause
Group:          System/Monitoring
Version:        0.1
Release:        112.2
URL:            https://github.com/nickanderson/check-sar-perf 
Source0:        nickanderson-check-sar-perf-4878d0c.tar.gz 
Source1:        check_iostat
Source2:        usr.lib.nagios.plugins.check_iostat
Patch0:         monitoring-plugins-sar-perf-output.patch
Patch1:         monitoring-plugins-sar-perf-stdout.patch
BuildRequires:  nagios-rpm-macros
%if 0%{?suse_version}
Recommends:     apparmor-profiles
%endif
Provides:       nagios-plugins-sar-perf = %{version}-%{release}
Obsoletes:      nagios-plugins-sar-perf < %{version}-%{release}
Requires:       python
Requires:       sysstat
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This plug-in was written to get performance data from sar. It was developed for
use with Zenoss but should work with other NRPE compatible NMS.

Example output:

check_sar_perf cpu
sar OK| CPU=all user=59.90 nice=0.00 system=4.46 iowait=0.00 steal=0.00
  idle=35.64

check_sar_perf disk sda
sar OK| DEV=sda tps=0.00 rd_sec/s=0.00 wr_sec/s=0.00 avgrq-sz=0.00
  avgqu-sz=0.00 await=0.00 svctm=0.00 util=0.00


%prep
%autosetup -p0 -n nickanderson-check-sar-perf-4878d0c

%build

%install
install -D -m755 check_sar_perf.py %{buildroot}/%{nagios_plugindir}/check_sar_perf
install -m755 %{SOURCE1} %{buildroot}/%{nagios_plugindir}/check_iostat
install -Dm0644 %{SOURCE2} %{buildroot}/%{_sysconfdir}/apparmor.d/usr.lib.nagios.plugins.check_iostat

%postun
if [ "$YAST_IS_RUNNING" != "instsys" ]; then
     if [ -x /sbin/apparmor_parser ]; then
         if /usr/bin/systemctl is-active --quiet apparmor.service; then
             /sbin/apparmor_parser -r -T -W  %{_sysconfdir}/apparmor.d/usr.lib.nagios.plugins.check_iostat &> /dev/null || :
         fi
     else
         echo "Could not reload the Apparmor profile: /sbin/apparmor_parser is missing or not executable."
     fi
fi

%clean
rm -rf %{buildroot}

%files 
%defattr(-,root,root)
# avoid build dependecy of nagios - own the dirs
%dir %{nagios_libdir}
%dir %{nagios_plugindir}
%dir %{_sysconfdir}/apparmor.d
%{nagios_plugindir}/check_sar_perf
%{nagios_plugindir}/check_iostat
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/apparmor.d/usr.lib.nagios.plugins.check_iostat

%changelog
* Fri Feb 23 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Thu Apr 22 2021 Lars Vogdt <lars@linux-schulserver.de>
- include abstractions/bash in apparmor profile - otherwise
  the 'which iostat' command fails
- reload the apparmor profile in postun to make the changes effective
* Tue Jul 28 2020 ro@suse.de
- update apparmor profile again to allow reading
  /sys/devices/**/stat
* Tue Jul  7 2020 lars@linux-schulserver.de
-  update AppArmor profiles to include a comment why the check
  needs to read nsswitch.conf and passwd
* Sun May 31 2020 Christian Boltz <suse-beta@cboltz.de>
- update AppArmor profile to allow reading /etc/nsswitch.conf and /etc/passwd
* Thu Mar 12 2020 ro@suse.de
- update apparmor profile usr.lib.nagios.plugins.check_iostat
  to allow reading / and /proc/$pid/mountinfo
* Fri Feb 28 2020 ro@suse.de
- check_iostat: add reasons why state is warning or critical
  to the output
* Wed Dec 11 2019 ro@suse.de
- check_iostat: sanitize dev name to properly match iostat output
* Thu Dec  5 2019 ro@suse.de
- check_iostat: exit with OK if running on tmpfs
- check_iostat: fix apparmor profile to allow stat call
* Thu Dec  5 2019 ro@suse.de
- check_iostat: allow to just specify a directory
* Sun Apr 14 2019 Christian Boltz <suse-beta@cboltz.de>
- update AppArmor profile for usrMerge (bash) (boo#1132350)
* Tue Apr 10 2018 ro@suse.de
- check_iostat: fix to work with iostat on sle15
* Wed Nov 15 2017 ro@suse.de
- check_iostat: get field numbers from iostat dynamically
  by parsing header line (r/s and w/s fields move between versions)
* Tue Nov 14 2017 ro@suse.de
- check_iostat: pass warning and critical level to perfdata
- use iostat fields r/s and w/s for tps calculation
* Mon Apr 24 2017 ro@suse.de
- use -x for iostat and add utilization monitoring
* Fri Oct 30 2015 lars@linux-schulserver.de
- switch to BSD-2-Clause as the script is more likely released
  under this license
* Sat Aug  1 2015 lars@linux-schulserver.de
- add apparmor profile for check_iostat
- recommend apparmor-profiles (needed for apparmor profile, but as
  the check itself runs without apparmor, we use a week dependency)
* Wed Jul 30 2014 lars@linux-schulserver.de
- Renamed package to monitoring-plugins-sar-perf
* Fri Nov  9 2012 ro@suse.de
- check_iostat: use 5 seconds instead of 2 to get more useful data
* Mon Nov 28 2011 ro@suse.de
- check_iostat: add warning and critical levels for iowait
* Sat Nov 26 2011 ro@suse.de
- check_iostat: actually check current io stats, not since boot
* Fri Nov 25 2011 ro@suse.de
- more additions to check_iostat: can use device-mapper name
* Fri Nov 25 2011 ro@suse.de
- rewrite check_iostat in perl, also output iowait value
* Fri Nov 25 2011 ro@suse.de
- add requires sysstat
- check_iostat: call iostat with "-k" to really display kb
  instead of blocks as unit
* Thu Nov 24 2011 lars@linux-schulserver.de
- added check_iostat
* Tue Oct  4 2011 lars@linux-schulserver.de
- also print the used arguments as output to STDOUT, so the user
  knows what is mesured (monitoring-plugins-sar-perf-stdout.patch)
* Tue Oct  4 2011 lars@linux-schulserver.de
- added monitoring-plugins-sar-perf-output.patch :
  do not print DEV name for disk in performance output
* Sun Jul 24 2011 lars@linux-schulserver.de
- initial version (git commit  4878d0cc66e928bd1075) defined as 0.1
